@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ChangelogFromGit;
 {
-  $Dist::Zilla::Plugin::ChangelogFromGit::VERSION = '0.007';
+  $Dist::Zilla::Plugin::ChangelogFromGit::VERSION = '0.014';
 }
 
 # Indent style:
@@ -20,6 +20,7 @@ use DateTime::Infinite;
 use Software::Release;
 use Software::Release::Change;
 use Git::Repository::Log::Iterator;
+use IPC::Cmd qw/run/;
 
 has max_age => (
 	is      => 'ro',
@@ -102,7 +103,8 @@ sub gather_files {
 
 	my $earliest_date = $self->earliest_date();
 
-	chomp(my @tags = `git tag`);
+	my @tags = $self->rungit([qw/git tag/]);
+	my @head_version_per_tag = ();
 
 	{
 		my $tag_pattern = $self->tag_regexp();
@@ -114,8 +116,14 @@ sub gather_files {
 				next;
 			}
 
-			my $commit = `git show $tags[$i] --pretty='tformat:(((((%ct)))))' | grep '(((((' | head -1`;
-			die $commit unless $commit =~ /\(\(\(\(\((\d+?)\)\)\)\)\)/;
+			my $commit = '';
+			foreach ($self->rungit(['git', 'show', "refs/tags/$tags[$i]", "--pretty='tformat:(((((%ct)))))"])) {
+				next if (! /\(\(\(\(\(/);
+				$commit = $_;
+				last;
+			}
+			die "Failed to find our pretty print format ((((( for tag $tags[$i]: $commit" unless $commit =~ /\(\(\(\(\((\d+?)\)\)\)\)\)/;
+			push(@head_version_per_tag, ($self->rungit(['git', 'rev-list', "refs/tags/$tags[$i]"]))[0]);
 
 			$self->push_release(
 				Software::Release->new(
@@ -131,10 +139,9 @@ sub gather_files {
 	# releases, up to "HEAD".
 
 	{
-		chomp( my $head_version = `git rev-list HEAD | tail -1` );
-		chomp( my $head_time    = `git show --format=%ct -n1 HEAD | head -1` );
+		my $head_version = ($self->rungit([qw/git rev-list HEAD/]))[0];
 
-		if ( not $self->all_releases or $head_version ne $self->get_release(-1)->version()) {
+		if ( not $self->all_releases or ! grep {$head_version eq $_} @head_version_per_tag) {
 			$self->push_release(
 				Software::Release->new(
 					date    => DateTime->now(),
@@ -399,6 +406,12 @@ sub format_datetime {
 	return $datetime->strftime("%F %T %z");
 }
 
+sub rungit {
+	my ($self, $arrayp) = @_;
+	my $buf;
+	run(command => $arrayp, buffer => \$buf);
+	return split("\n", $buf);
+}
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
@@ -411,7 +424,7 @@ Dist::Zilla::Plugin::ChangelogFromGit - Write a Changes file from a project's gi
 
 =head1 VERSION
 
-version 0.007
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -932,7 +945,7 @@ overridable.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010-2011 by Rocco Caputo.
+This software is copyright (c) 2010-2013 by Rocco Caputo.
 
 This is free software; you may redistribute it and/or modify it under
 the same terms as the Perl 5 programming language itself.
